Index: include/core/SkOSFile.h |
diff --git a/include/core/SkOSFile.h b/include/core/SkOSFile.h |
index c9fa37ad164c1e46e05d9dd073b3435d33313c3a..1ca11ee932ad19504a1681fee0b162ff2e029f34 100644 |
--- a/include/core/SkOSFile.h |
+++ b/include/core/SkOSFile.h |
@@ -77,8 +77,10 @@ bool sk_fidentical(SkFILE* a, SkFILE* b); |
*/ |
int sk_fileno(SkFILE* f); |
-// Returns true if something (file, directory, ???) exists at this path. |
-bool sk_exists(const char *path); |
+/** Returns true if something (file, directory, ???) exists at this path, |
+ * and has the specified access flags. |
+ */ |
+bool sk_exists(const char *path, SkFILE_Flags = (SkFILE_Flags)0); |
// Returns true if a directory exists at this path. |
bool sk_isdir(const char *path); |